function sample = DISCRETE_RND(state,prob,ndraws)

% Purpose: 
% Generate random numbers from discrete distribution with specified prob.
% -----------------------------------
% Density:
% Prob(xi) = Pi
% -----------------------------------
% Algorithm: 
% Inverse CDF
% -----------------------------------
% Usage:
% state = a vector of discrete state
% prob = a vector specifying the probability on each state
% ndraws = number of draws 
% -----------------------------------
% Returns:
% sample = random numbers from distribution distribution
% -----------------------------------
% Notes:
% If the prob vector does not sum up to one, the program will normalize it
% If the prob vector is missing, a discrete uniform distribution is assumed.
%
% Written by Hang Qian, Iowa State University
% Contact me:  matlabist@gmail.com

if nargin == 2
    if isscalar(prob) && prob > 1
        ndraws = prob;
        prob = ones(length(state),1);
    else
        if length(state) ~= length(prob)
            error('State and probability vector must match in length.')
        end
        ndraws = 1;
    end    
end

if nargin == 1
    ndraws = 1;
    prob = ones(length(state),1);
end


cum_prob = cumsum(prob);
cum_prob = cum_prob ./ cum_prob(end);

state_index = zeros(ndraws,1);
for m = 1:ndraws
    state_index(m) = find(cum_prob>rand,1);
end

sample = state(state_index);


